from django.contrib import auth
from django.core.mail import EmailMessage
from django.http import HttpResponse
from django.shortcuts import redirect, render
from django.utils.translation import ugettext as _
from pam import pam
import pexpect

from .forms import ChPwForm, LoginForm, RegisterForm
from .models import TeckidsGroup, TeckidsPerson

def login(request):
    context = {}
    login_form = LoginForm()

    if request.method == 'POST':
        login_form = LoginForm(request.POST)
        if login_form.is_valid():
            user = auth.authenticate(request,
                username=login_form.cleaned_data['uid'], password=login_form.cleaned_data['password'])
            if user:
                auth.login(request, user)

                # Trigger PAM once to ensure Kerberos principal creation
                pam().authenticate(login_form.cleaned_data['uid'],
                    login_form.cleaned_data['password'], service='ticdesk')

                if request.GET.get('next'):
                    next = request.GET['next']
                else:
                    next = '/'
                return redirect(next)
            else:
                context['error'] = _('Benutzername oder Passwort falsch')

    context['login_form'] = login_form
    return render(request, 'ticdesk_account/login.html', context)

def logout(request):
    auth.logout(request)
    return redirect('/')

def change_password(request):
    context = {}
    chpw_form = ChPwForm()
    
    if request.user.is_anonymous():
        return HttpResponse(status=403)

    if request.method == 'POST':
        chpw_form = ChPwForm(request.POST)
        if chpw_form.is_valid():
            # Trigger PAM once to ensure password is correct
            ret = pam().authenticate(request.user.username,
                chpw_form.cleaned_data['password_old'], service='ticdesk')

            if ret:
                # Do expect conversation with passwd as logged-in user
                child = pexpect.spawn('su -c passwd %s' % request.user.username)
                # Password prompt from su
                child.expect('[Pp]assword: ')
                child.sendline(chpw_form.cleaned_data['password_old'])
                # Old password prompt from pam_krb5
                child.expect('[Cc]urrent [Kk]erberos [Pp]assword: ')
                child.sendline(chpw_form.cleaned_data['password_old'])
                # New password prompt from pam_krb5
                child.expect('[Ee]nter new [Kk]erberos [Pp]assword: ')
                child.sendline(chpw_form.cleaned_data['password_new'])
                # Confirm new password prompt from pam_krb5
                child.expect('[Rr]etype new [Kk]erberos [Pp]assword: ')
                child.sendline(chpw_form.cleaned_data['password_new'])
                # Wait for the child to exit
                child.expect('passwd: password updated successfully')
                child.wait()

                # Try new password
                ret = pam().authenticate(request.user.username,
                    chpw_form.cleaned_data['password_new'], service='ticdesk')

                if ret:
                    context['success'] = True
                else:
                    context['error'] = _('Fehler beim Ändern des Passworts.')
            else:
                context['error'] = _('Das angegebene alte Passwort ist falsch!')

    context['chpw_form'] = chpw_form
    return render(request, 'ticdesk_account/change_password.html', context)

def register(request):
    context = {}
    register_form = RegisterForm(initial={'newsletter': 'none'})

    if request.method == 'POST':
        register_form = RegisterForm(request.POST)
        if register_form.is_valid():
            person = TeckidsPerson.create_person(register_form.cleaned_data['uid'], register_form.cleaned_data['given_name'],
                         register_form.cleaned_data['sn'], register_form.cleaned_data['date_of_birth'],
                         register_form.cleaned_data['mail'], register_form.cleaned_data['password'])

            if not person:
                context['registered'] = False
                context['error'] = _('Anlegen des Benutzers fehlgeschlagen. Bitte versuche es später erneut!')
            else:
                # Do newsletter registration, if desired
                if register_form.cleaned_data['newsletter'] != 'none':
                    person.subscribe_newsletter(register_form.cleaned_data['newsletter'])

                # E-mail user and admins
                message = EmailMessage()
                message.reply_to = ['root@teckids.org']
                message.to = [register_form.cleaned_data['mail']]
                message.cc = ['root@teckids.org']
                message.subject = _('Teckids-Account %s angelegt') % register_form.cleaned_data['uid']
                message.extra_headers = {
                    'X-OTRS-CustomerUser': register_form.cleaned_data['uid']
                }
                message.body = _("""
Hallo %s,

dein Teckids-Account mit dem Benutzernamen %s wurde angelegt.

Bitt halte dich immer an die Nutzungsbedingungen:
https://www.teckids.org/de/kleingedrucktes/nutzungsbedingungen/

Bei Fragen oder Problemen schreibe bitte eine E-Mail an
verein@teckids.org.

Viel Spaß,
dein Teckids-Team
""") % (register_form.cleaned_data['given_name'], register_form.cleaned_data['uid'])
                message.send()
            
                context['registered'] = True

    context['register_form'] = register_form
    return render(request, 'ticdesk_account/register.html', context)
