from django import forms
from django.utils.translation import ugettext_lazy as _

CHANNEL_CHOICES = {
    ('none', _('Keine Angabe')),
    ('internet', _('Aus dem Internet')),
    ('school', _('Aus der Schule')),
    ('friends', _('Von Freunden')),
    ('parents', _('Durch meine Eltern')),
    ('newsletter', _('Durch den Newsletter')),
}

SEX_CHOICES = {
    ('f', _('Mädchen (weiblich)')),
    ('m', _('Junge (männlich)')),
}

class EventRegisterForm(forms.Form):
    cn = forms.CharField(label=_('Dein Name'), disabled=True)
    date_of_birth = forms.DateField(label=_('Dein Geburtsdatum'), disabled=True)
    sex = forms.ChoiceField(label=_('Dein Geschlecht'), choices=SEX_CHOICES, widget=forms.RadioSelect,
        help_text=_('Aus verschiedenen Gründen, z.B. weil wir während der Übernachtungen aus rechtlichen Gründen Geschlechtertrennung einhalten müssen, müssen wir wissen, ob du ein Junge oder Mädchen bist. Bei manchen Namen ist das nicht immer sofort zu erkennen, daher bitten wir dich, es hier anzugeben.')
    )
    mail = forms.EmailField(label=_('Deine E-Mail-Adresse'), disabled=True)
    
    street = forms.CharField(label=_('Straße und Hausnummer'))
    postal_code = forms.CharField(label=_('Postleitzahl (PLZ)'))
    place = forms.CharField(label=_('Ort'))

    # FIXME add validation
    mobile = forms.CharField(required=False, label=_('Deine Handynummer'),
        help_text=_('Deine Handynummer hilft uns, dich im Notfall während der Veranstaltung zu erreichen, z.B. wenn du mit deiner Gruppe alleine auf eienr Konferenz o.ä. unterwegs bist. Solltest du kein Handy haben, kannst du das Feld leer lassen.')
    )

    school = forms.CharField(label=_('Schule'),
        help_text=_('Bitte gib den Namen deiner Schule möglichst genau so ein, wie er offiziell geschrieben wird.'))
    school_place = forms.CharField(label=_('Ort der Schule'),
        help_text=_('Gib hier den Ort (die Stadt) ein, in der deine Schule liegt (ohne Ortsteil).'))
    school_class = forms.CharField(label=_('Klasse'),
        help_text=_('Bitte gib die Klasse an, in die du gehst (z.B. 8a).'))

    # FIXME add full-featured guardian management
    guardian_name = forms.CharField(label=_('Vor- und Nachname eines Erziehungsberechtigten'),
        help_text=_('Bitte gib hier den Namen des Erziehungsberechtigten an, der die Anmeldung mit dir ausfüllt und im Notfall während der Veranstaltung erreichbar ist.')
    )
    guardian_mail = forms.EmailField(label=_('E-Mail-Adresse des Erziehungsberechtigten'))
    guardian_mobile = forms.CharField(label=_('Handynummer des Erziehungsberechtigten'),
        help_text=_('Die Handynummer benötigen wir für Notfälle, falls wir deine Eltern während der Veranstaltung dringend erreichen müssen.')
    )

    channel = forms.ChoiceField(label=_('Wie hast du von der Veranstaltung erfahren?'), choices=CHANNEL_CHOICES)
    comment = forms.CharField(required=False, label=_('Kommentar / Bemerkungen'), widget=forms.Textarea)

    donation = forms.IntegerField(required=False, min_value=0, label=_('Freiwilliger Mehrbetrag'),
        help_text=_('Unser Verein möchte allen Kindern und Jugendlichen die Möglichkeit bieten, an unseren Veranstaltungen teilzunehmen. Oft ist der Teilnehmerbeitrag für eine Familie jedoch nicht aufzubringen. Wir halten deshalb einen Etat bereit, aus dem wir Teilnahmen fördern können, nachdem wir die Notwendigkeit und Berechtigung sorgfältig geprüft haben. Für diesen Etat sind wir auf Spenden angewiesen. Wenn Sie einen freiwilligen Mehrbetrag für diesen Etat spenden möchten, geben Sie dies bitte hier an. Ob und wenn ja in welcher Höhe gespendet wurde, wird von uns nicht dauerhaft gespeichert und auch nicht innerhalb des Vereins, z.B. an Freizeitbetreuer, weitergegeben.')
    )

    accept_sepa = forms.BooleanField(required=False, label=_('Per SEPA-Lastschrift bezahlen'),
        help_text=_('Eltern: Ich ermächtige den Gläubiger Teckids e.V., Rochusstr. 2-4, 53123 Bonn mit der Gläubiger-ID DE70FZT00001497650, den Teilnehmerbeitrag von meinem Konto einmalig mit dem SEPA-Basislastschriftverfahren einzuziehen. Gleichzeitig weise ich meine Bank an, die vom Teckids e.V. von meinem Konto eingezogene SEPA-Basislastschrift einzulösen.')
    )

    # FIXME add validation
    iban = forms.CharField(required=False, label=_('IBAN (für SEPA-Lastschriftverfahren)'),
        help_text=_('Wenn deine Eltern per SEPA-Lastschrift bezahlen möchten, lasse sie bitte dieses Feld ausfüllen.')
    )

    accept_terms = forms.BooleanField(label=_('Einverständniserklärung Eltern'),
        help_text=_('Eltern: Mein Kind hat das Anmeldeformular gemeinsam mit mir ausgefüllt und ich bin mit der Teilnahme einverstanden. Mir ist bewusst, dass die Anmeldung verbindlich ist und ein Rücktritt nur in Ausnahmefällen mit triftigem Grund möglich ist. Darüberhinaus erkläre ich mich einverstanden, den Teilnehmerbeitrag vorab zu begleichen und erkläre mich mit den oben genannten Erstattungsrichtlinien einverstanden.')
    )
