import logging

from django.apps import apps

TeckidsPerson = apps.get_model('ticdesk_account', 'TeckidsPerson')
TeckidsGroup = apps.get_model('ticdesk_account', 'TeckidsGroup')

logger = logging.getLogger(__name__)

def may_see_group(group, user):
    # Not logged-in users cannot see anything
    if not user.is_authenticated():
        return False

    # Replace user variable it the user's TeckidsPerson
    user = TeckidsPerson.objects.get(uid=user.username)

    # Board members can see everything
    if user.is_board:
        return True

    # Members of pedagogic board can see everything
    if user.is_paeda:
        return True

    # Owners of the group may see the group
    if user in group.owners_persons:
        return True

    # Secure fallback to False
    logger.warning("%s tried to access disallowed group %s" % (user.uid, group.dn))
    return False

def may_see_person(person, user):
    # Not logged-in users cannot see anything
    if not user.is_authenticated():
        return False

    # Replace user variable with the user's TeckidsPerson
    user = TeckidsPerson.objects.get(uid=user.username)

    # Everyone can see themselves
    if user == person:
        return True

    # Board members can see everything
    if user.is_board:
        return True

    # Members of pedagogic board can see everything
    if user.is_paeda:
        return True

    # Secure fallback to False
    logger.warning("%s tried to access disallowed person %s" % (user.uid, person.dn))
    return False

def filter_disallowed_persons(persons, user):
    return [person for person in persons if may_see_person(person, user)]

def get_relevant_groups(user):
    # Not logged-in users cannot see anything
    if not user.is_authenticated():
        return []

    # Replace user variable with the user's TeckidsPerson
    user = TeckidsPerson.objects.get(uid=user.username)

    relevant = []
    for group in TeckidsGroup.objects.all():
        # Skip if group is a privilege - these are special
        if group.group_type[0] == 'privilege':
            continue

        # Skip if group is a project/event - these are special
        if group.group_type[0] == 'project':
            continue

        # Skip if group is a newsletter - these are special
        if group.group_type[0] == 'newsletter':
            continue

        # If person is a board member, everything is relevant
        if user.is_board:
            relevant.append(group)
            continue

        # If person is a member of the pedagogic board, everything is relevant
        if user.is_paeda:
            relevant.append(group)
            continue

        # If the person is an owner of the group, it is relevant
        if user in group.owners_persons:
            relevant.append(group)
            continue

    return relevant
