from django.apps import apps
from django.http import HttpResponse
from django.shortcuts import redirect, render
from django.urls import reverse
from django_tables2 import RequestConfig

from .tables import PersonTable
from .util import filter_disallowed_persons, get_relevant_groups, may_see_group, may_see_person

TeckidsPerson = apps.get_model('ticdesk_account', 'TeckidsPerson')
TeckidsGroup = apps.get_model('ticdesk_account', 'TeckidsGroup')

def person(request, uid=None):
    context = {}

    # Do not allow not logged-in users
    if request.user.is_anonymous():
        return HttpResponse(status=403)

    # Redirect to own listing if no uid given
    if uid is None:
        return redirect(reverse('person_by_uid', args=[request.user.username]))

    # Get person and check access    
    person = TeckidsPerson.objects.get(uid=uid)
    if not may_see_person(person, request.user):
        return HttpResponse(status=403)
    else:
        # Save person once to clean it, then add to context
        try:
            person.save()
        except:
            # Not being able to save here does not matter
            pass

        context['person'] = person

    # Add information for menu
    context['relevant_groups'] = get_relevant_groups(request.user)

    return render(request, 'ticdesk_org/person.html', context)

def persons(request, group=None):
    context = {}

    # Determine group pre-filter
    if group is None:
        persons = TeckidsPerson.objects.all()
    else:
        group = TeckidsGroup.objects.get(cn=group)

        if not may_see_group(group, request.user):
            return HttpResponse(status=403)
        else:
            persons = group.members_persons
            context['group'] = group

    # Evaluate QuerySet and filter for allowed persons
    persons = filter_disallowed_persons(list(persons), request.user)

    # Build table
    person_table = PersonTable(persons)
    RequestConfig(request, paginate={'per_page': 25}).configure(person_table)
    context['person_table'] = person_table

    # Add information for menu
    context['relevant_groups'] = get_relevant_groups(request.user)

    return render(request, 'ticdesk_org/persons.html', context)
